<?php
namespace WPDesk\FPF\Pro\Hookable\Product;

use FPF_Product;
use FPFProVendor\WPDesk\PluginBuilder\Plugin\Hookable;

/**
 * Ajax action for reloading fields on product page.
 */
class AjaxFieldsLoader implements Hookable {

	private FPF_Product $fpf_product;

	private const ACTION = 'fpf_fields';

	public function __construct( FPF_Product $fpf_product ) {
		$this->fpf_product = $fpf_product;
	}

	public function hooks() {
		\add_action( 'wp_ajax_' . self::ACTION, [ $this, 'get_fields' ] );
		\add_action( 'wp_ajax_nopriv_' . self::ACTION, [ $this, 'get_fields' ] );
	}

	public function get_fields(): void {
		if ( ! isset( $_POST['nonce'] ) || ! \wp_verify_nonce( \sanitize_text_field( \wp_unslash( $_POST['nonce'] ) ), 'fpf_pro_front' ) ) {
			\wp_send_json_error( 'Invalid nonce' );
		}

		$product_id = \sanitize_key( $_POST['product_id'] ?? 0 );
		$product    = \wc_get_product( $product_id );

		if ( ! $product instanceof \WC_Product ) {
			\wp_send_json_error( 'Invalid variation' );
		}

		$response = [
			'html_before'       => $this->fpf_product->render_fields_before_add_to_cart( $product ),
			'html_after'        => $this->fpf_product->render_fields_after_add_to_cart( $product ),
			'fpf_fields'        => $this->fpf_product->get_fields_data( $product ),
			'fpf_product_price' => $this->fpf_product->get_product_price_data( $product ),
			'fields_rules'      => $this->fpf_product->get_logic_rules_for_product( $product ),
			'product_id'        => $product_id,
		];

		\wp_send_json_success( $response );
	}
}
